@@ -1,9 +1,14 @@
 from datetime import datetime
-from typing import Literal
+from typing import Literal, Optional
 import secrets
 
 from pydantic import BaseModel, EmailStr
 
+inactive_roles = [
+    "unconfirmed",
+    "inactive",
+]
+
 
 class User(BaseModel):
     username: str
